let data;

const xLabel = "Total Generation (TWh)";
const yLabel = "Share of production (%)";

const fetchCSV = async() => {
    //fetch csv data
    const pathToCSV = "https://gist.githubusercontent.com/colmpat/27d2bc0d7bc82142ffd2c16f51597c4a/raw/0a6506e81c00f310ba2d535398fbddd2084c3fcd/Europe_Power_Sector_Total_Production_vs_Renewable_Share.csv";
    
    data = await d3.csv(pathToCSV, d => {
        return {
            area: d["Area"],
            production: parseFloat(d[xLabel]),
            share: parseFloat(d[yLabel])
        };
    });
    
}

const drawPlot = async() => {

    //load in csv
    try {
        await fetchCSV();
    } catch (e) {
        console.log("there was an error loading the csv file:\n", e);
    }

    let canvasWidth = 800;
    let canvasHeight = 500;
    let margin = 150;
    let w = canvasWidth - margin;
    let h = canvasHeight - margin;

    let svg = d3.select("body").append("svg")
        .attr("width", canvasWidth)
        .attr("height", canvasHeight);

    //------axis scales-------------
    let xScale = d3.scaleLinear()
        .domain([0, d3.max(data.map(d => d.production))])
        .range([0, w]);
    let xAxis = d3.axisBottom(xScale);

    let yScale = d3.scaleLinear()
        .domain([Math.floor(d3.min(data.map(d => d.share))), Math.ceil(d3.max(data.map(d => d.share)))])
        .range([h, 0]);
    let yAxis = d3.axisLeft(yScale)
        .tickFormat(d => d + "%");

    //------Title-----------
    svg.append("text")
        .attr("text-anchor", "middle")
        .attr("x", canvasWidth / 2)
        .attr("y", 30)
        .text("Avg. Share of Production for Renewables vs. Total Power Generation in 2020");

    //label x
    svg.append("text")
        .attr("class", "x label")
        .attr("text-anchor", "middle")
        .attr("x", canvasWidth / 2)
        .attr("y", canvasHeight - 15)
        .text(xLabel)

    //label y
    svg.append("text")
        .attr("class", "y label")
        .attr("transform", "rotate(-90)")
        .attr("text-anchor", "middle")
        .attr("x", canvasHeight / -2)
        .attr("y", 22)
        .text(yLabel)

    //prepare plot container
    let container_g = svg.append("g")
        .attr("transform", `translate(${margin / 2}, ${margin / 2})`);

    //draw x and y axis
    container_g.append("g")
        .attr("transform", `translate(0, ${h})`)
        .call(xAxis);
    container_g.append("g")
        .call(yAxis);


    //draw dots
    container_g.selectAll(".dot")
        .data(data)
        .enter()
        .append("circle")
        .attr("class", "dot")
        .attr("r", 5)
        .attr("cx", d => xScale(d.production))
        .attr("cy", d => h - yScale(d.share));

}

drawPlot();
